@@ -1215,8 +1215,8 @@ impl NodeMetrics {
 				}
 			};
 			return false; // Continue processing for records stored (parse_states())
-		} else if line.contains("after earning ") {
-			if let Some(attos_earned) = self.parse_u64("after earning ", line) {
+		} else if line.contains("Total payment of") {
+			if let Some(attos_earned) = self.parse_u64("Total payment of", line) {
 				self.count_attos_earned(entry_time, attos_earned);
 				self.parser_output = format!("Payment received: {}", attos_earned);
 				return true;
@@ -1290,7 +1290,7 @@ impl NodeMetrics {
 			return true;
 		}
 
-		if content.contains("Cost is now") {
+		if content.contains("Created payment quote for") {
 			if let Some(records_stored) = self.parse_u64("records_stored: ", line) {
 				self.records_stored = records_stored;
 				self.parser_output = format!("Records stored: {}", records_stored);
@@ -1312,7 +1312,7 @@ impl NodeMetrics {
 		// }
 
 		// Metrics
-		if content.contains("sn_logging::metrics") {
+		if content.contains("ant_logging::metrics") {
 			// System
 			let mut parser_output = String::from("system_cpu_usage_percent:");
 			if let Some(system_cpu) = self.parse_float32("system_cpu_usage_percent\":", content) {
